@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-tray-extension.c,v 1.10 2005/01/13 16:15:46 chpe Exp $
+ *  $Id: ephy-bookmarks-tray-extension.c,v 1.12 2005/01/28 22:29:03 chpe Exp $
  */
 
 #include "config.h"
@@ -99,7 +99,6 @@ struct _EphyBookmarksTrayExtensionPrivate
 #define STOCK_NEW_TAB		"stock_new-tab"
 
 static void ephy_bookmarks_tray_extension_class_init	(EphyBookmarksTrayExtensionClass *klass);
-static void ephy_bookmarks_tray_extension_iface_init	(EphyExtensionIface *iface);
 static void ephy_bookmarks_tray_extension_init		(EphyBookmarksTrayExtension *extension);
 
 static GObjectClass *parent_class = NULL;
@@ -128,23 +127,11 @@ ephy_bookmarks_tray_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_bookmarks_tray_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
-	{
-		(GInterfaceInitFunc) ephy_bookmarks_tray_extension_iface_init,
-		NULL,
-		NULL
-	};
-
 	type = g_type_module_register_type (module,
 					    G_TYPE_OBJECT,
 					    "EphyBookmarksTrayExtension",
 					    &our_info, 0);
 
-	g_type_module_add_interface (module,
-				     type,
-				     EPHY_TYPE_EXTENSION,
-				     &extension_info);
-
 	return type;
 }
 
@@ -283,7 +270,7 @@ show_context_menu (EphyBookmarksTrayExtension *extension,
 	EphyBookmarksTrayExtensionPrivate *priv = extension->priv;
 	GtkWidget *menu;
 
-	LOG ("show_context_menu")
+	LOG ("show_context_menu");
 
 	menu = gtk_ui_manager_get_widget (priv->manager, "/ContextMenu");
 	g_return_if_fail (menu != NULL);
@@ -341,7 +328,7 @@ static void
 button_toggled_cb (GtkToggleButton *button,
 		   EphyBookmarksTrayExtension *extension)
 {
-	LOG ("button_toggled_cb")
+	LOG ("button_toggled_cb");
 
 	if (gtk_toggle_button_get_active (button))
 	{
@@ -361,7 +348,7 @@ button_button_press_cb (GtkWidget *button,
 			GdkEventButton *event,
 			EphyBookmarksTrayExtension *extension)
 {
-	LOG ("button_button_press_cb")
+	LOG ("button_button_press_cb");
 
 	if (event->button == 3)
         {
@@ -377,7 +364,7 @@ static gboolean
 button_popup_menu_cb (GtkWidget *button,
 		      EphyBookmarksTrayExtension *extension)
 {
-	LOG ("button_popup_menu_cb")
+	LOG ("button_popup_menu_cb");
 
 	show_context_menu (extension, button, NULL);
 
@@ -466,7 +453,7 @@ ephy_bookmarks_tray_extension_init (EphyBookmarksTrayExtension *extension)
 	GError *error = NULL;
 	GtkWidget *hbox, *image, *label;
 
-	LOG ("EphyBookmarksTrayExtension initialising")
+	LOG ("EphyBookmarksTrayExtension initialising");
 
 	priv = extension->priv = EPHY_BOOKMARKS_TRAY_EXTENSION_GET_PRIVATE (extension);
 
@@ -549,7 +536,7 @@ ephy_bookmarks_tray_extension_finalize (GObject *object)
 	EphyBookmarksTrayExtension *extension = EPHY_BOOKMARKS_TRAY_EXTENSION (object);
 	EphyBookmarksTrayExtensionPrivate *priv = extension->priv;
 
-	LOG ("EphyBookmarksTrayExtension finalising")
+	LOG ("EphyBookmarksTrayExtension finalising");
 
 	eel_gconf_monitor_remove (CONF_DIR);
 
@@ -562,29 +549,6 @@ ephy_bookmarks_tray_extension_finalize (GObject *object)
 	parent_class->finalize (object);
 }
 
-static void
-impl_attach_window (EphyExtension *ext,
-		    EphyWindow *window)
-{
-//	EphyBookmarksTrayExtension *extension = EPHY_BOOKMARKS_TRAY_EXTENSION (ext);
-	LOG ("EphyBookmarksTrayExtension attach_window")
-}
-
-static void
-impl_detach_window (EphyExtension *ext,
-		    EphyWindow *window)
-{
-//	EphyBookmarksTrayExtension *extension = EPHY_BOOKMARKS_TRAY_EXTENSION (ext);
-	LOG ("EphyBookmarksTrayExtension detach_window")
-}
-
-static void
-ephy_bookmarks_tray_extension_iface_init (EphyExtensionIface *iface)
-{
-	iface->attach_window = impl_attach_window;
-	iface->detach_window = impl_detach_window;
-}
-
 static void
 ephy_bookmarks_tray_extension_class_init (EphyBookmarksTrayExtensionClass *klass)
 {
