@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.2 2005/01/13 16:15:46 chpe Exp $
+ *  $Id: extension.c,v 1.3 2005/01/28 22:29:03 chpe Exp $
  */
 
 #include "config.h"
@@ -32,7 +32,7 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering EphyBookmarksTrayExtension")
+	LOG ("Registering EphyBookmarksTrayExtension");
 
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
