@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerConsoleListener.cpp,v 1.10 2004/12/08 15:33:52 chpe Exp $
+ *  $Id: ErrorViewerConsoleListener.cpp,v 1.11 2005/01/28 22:29:34 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -49,7 +49,7 @@ ErrorViewerConsoleListener::ErrorViewerConsoleListener()
 
 ErrorViewerConsoleListener::~ErrorViewerConsoleListener()
 {
-	LOG ("ErrorViewerConsoleListener dtor %p", this)
+	LOG ("ErrorViewerConsoleListener dtor %p", this);
 }
 
 nsresult
