@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.20 2005/01/23 23:12:11 chpe Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.21 2005/01/28 22:30:05 chpe Exp $
  */
 
 #include "config.h"
@@ -243,7 +243,7 @@ gesture_performed_cb (EphyGesture *gesture,
 	EphyWindow *window;
 	const char *path;
 
-	LOG ("Gesture: sequence '%s'", sequence)
+	LOG ("Gesture: sequence '%s'", sequence);
 
 	path = g_hash_table_lookup (extension->priv->gestures, sequence);
 	if (path == NULL)
@@ -334,7 +334,7 @@ impl_attach_tab (EphyExtension *extension,
 {
 	EphyEmbed *embed;
 
-	LOG ("Attach tab")
+	LOG ("Attach tab");
 
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
@@ -352,7 +352,7 @@ impl_detach_tab (EphyExtension *extension,
 {
 	EphyEmbed *embed;
 
-	LOG ("Detach tab")
+	LOG ("Detach tab");
 
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
