@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.cpp,v 1.19 2004/12/30 21:56:01 chpe Exp $
+ *  $Id: mozilla-helpers.cpp,v 1.25 2005/02/07 15:36:15 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -77,7 +77,6 @@
 #include <nsIDOMTreeWalker.h>
 #include <nsIDOMViewCSS.h>
 #include <nsIDOMWindow.h>
-#include <nsIHTMLDocument.h>
 #include <nsIInterfaceRequestorUtils.h>
 #include <nsIPrefBranch.h>
 #include <nsIPrefService.h>
@@ -277,9 +276,14 @@ PageInfoHelper::GetCacheEntryDescriptor (const nsAString &aUrl,
   
       nsCOMPtr<nsICacheEntryDescriptor> cacheEntryDescriptor;
   
+#ifdef MOZ_NSICACHESESSION_OPENCACHEENTRY_NSACSTRING_
+      rv = cacheSession->OpenCacheEntry (nsEmbedCString(url), nsICache::ACCESS_READ,
+                                         PR_FALSE, aEntry);
+#else
       rv = cacheSession->OpenCacheEntry (url, nsICache::ACCESS_READ,
                                          PR_FALSE, aEntry);
-  
+#endif
+
       if (NS_SUCCEEDED (rv)) break;
     }
 
@@ -364,10 +368,27 @@ PageInfoHelper::GetProperties ()
     }
 
   /* Might not work on XUL pages */
-  nsCOMPtr<nsIHTMLDocument> htmlDoc (do_QueryInterface (mDOMDocument));
+  /* FIXME doesn't get almost-standards mode. Use method from
+   * bug https://bugzilla.mozilla.org/show_bug.cgi?id=154359 when available.
+   */
+  nsCOMPtr<nsIDOMNSHTMLDocument> htmlDoc (do_QueryInterface (mDOMDocument));
   if (htmlDoc)
     {
-      props->rendering_mode = (EmbedPageRenderMode) htmlDoc->GetCompatibilityMode();
+      nsEmbedString mode;
+      rv = htmlDoc->GetCompatMode (mode);
+      if (NS_SUCCEEDED (rv) && mode.Length ())
+        {
+	  nsEmbedCString cMode;
+	  NS_UTF16ToCString (mode, NS_CSTRING_ENCODING_UTF8, cMode);
+	  if (strcmp (cMode.get(), "CSS1Compat") == 0)
+	    {
+	      props->rendering_mode = EMBED_RENDER_FULL_STANDARDS;
+	    }
+	  else
+	    {
+	      props->rendering_mode = EMBED_RENDER_QUIRKS;
+	    }
+	}
     }
 
   /* Get the URL so we can look in the cache for this page */
@@ -790,8 +811,11 @@ PageInfoHelper::WalkTree (nsIDOMDocument *aDocument)
   rv = EphyUtils::NewURI (getter_AddRefs (mBaseURI), spec, mDocCharset.get(), nsnull);
   if (NS_FAILED (rv) || !mBaseURI) return;
 
+  nsCOMPtr<nsIDOMNode> rootNode (do_QueryInterface (htmlDoc));
+  if (!rootNode) return;
+
   nsCOMPtr<nsIDOMTreeWalker> walker;
-  rv = trav->CreateTreeWalker(htmlDoc,
+  rv = trav->CreateTreeWalker(rootNode,
                               nsIDOMNodeFilter::SHOW_ELEMENT,
                               nsnull,
                               PR_TRUE,
@@ -983,7 +1007,7 @@ free_embed_page_form (EmbedPageForm *form)
   g_free (form);
 }
 
-extern "C" void
+static void
 mozilla_free_page_properties (EmbedPageProperties *props)
 {
   g_free (props->content_type);
@@ -1004,6 +1028,8 @@ mozilla_free_embed_page_info (EmbedPageInfo *info)
   g_list_foreach (info->media, (GFunc) free_embed_page_medium, NULL);
   g_list_free (info->media);
 
+  mozilla_free_page_properties (info->props);
+
   g_free (info);
 }
 
