@@ -22,12 +22,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: page-info-dialog.c,v 1.37 2005/01/05 21:07:49 jframeau Exp $
+ *  $Id: page-info-dialog.c,v 1.39 2005/01/28 22:30:13 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "page-info-dialog.h"
 #include "ephy-debug.h"
@@ -627,7 +625,7 @@ general_info_page_fill (InfoPage *page)
 	struct tm tm;
 	time_t t;
 
-	LOG ("general_info_page_fill")
+	LOG ("general_info_page_fill");
 
 	props = dialog->priv->page_info->props;
 	g_return_if_fail (props != NULL);
@@ -1881,7 +1879,7 @@ page_info_dialog_finalize (GObject *object)
 	PageInfoDialog *dialog = PAGE_INFO_DIALOG (object);
 	int i;
 
-	LOG ("PageInfoDialog finalizing")
+	LOG ("PageInfoDialog finalizing");
 
 	mozilla_free_embed_page_info (dialog->priv->page_info);
 	for (i = GENERAL_PAGE; i < LAST_PAGE; i++)
