@@ -17,12 +17,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.cpp,v 1.8 2004/11/15 15:07:37 chpe Exp $
+ *  $Id: mozilla-helpers.cpp,v 1.9 2004/12/08 15:33:53 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
+#include "mozilla-config.h"
+
 #include "config.h"
-#endif
 
 #include "mozilla-helpers.h"
 
