@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sidebar-extension.c,v 1.5 2005/01/13 16:15:49 chpe Exp $
+ *  $Id: ephy-sidebar-extension.c,v 1.6 2005/01/28 22:30:29 chpe Exp $
  */
 
 #include "config.h"
@@ -426,7 +426,7 @@ impl_attach_window (EphyExtension *ext,
 	const char * current_page;
 	gboolean show_sidebar;
 
-	LOG ("EphySidebarExtension attach_window")
+	LOG ("EphySidebarExtension attach_window");
 	
 	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 
@@ -540,7 +540,7 @@ impl_detach_window (EphyExtension *ext,
 	GtkWidget *notebook, *parent;
 	GValue position = {0,};
 
-	LOG ("EphySidebarExtension detach_window")
+	LOG ("EphySidebarExtension detach_window");
 
 	/* Remove UI */
 	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
@@ -628,7 +628,7 @@ ephy_sidebar_extension_finalize (GObject *object)
 	EphySidebarExtension *extension = EPHY_SIDEBAR_EXTENSION (object);
 	GObject *single;
 
-	LOG ("EphySidebarExtension finalising")
+	LOG ("EphySidebarExtension finalising");
 
 	ephy_node_db_write_to_xml_safe
 		(extension->priv->db, 
